/*
 * Created by Stefan Korecko, 2020
 * Parametric Hash Router roues and related functions
 */

//an array, defining the routes
export default [

    {
        //the part after '#' in the url (so-called fragment):
        hash:"welcome",
        ///id of the target html element:
        target:"router-view",
        //the function that returns content to be rendered to the target html element:
        getTemplate:(targetElm) =>
            document.getElementById(targetElm).innerHTML = document.getElementById("template-welcome").innerHTML
    },

    {
        hash:"articles",
        target:"router-view",
        getTemplate:(targetElm) =>
            document.getElementById(targetElm).innerHTML = document.getElementById("template-articles").innerHTML
    },

    {
        hash:"opinions",
        target:"router-view",
        getTemplate: createHtml4opinions
    },

    {
        hash:"addOpinion",
        target:"router-view",
        getTemplate: (targetElm) =>
            document.getElementById(targetElm).innerHTML = document.getElementById("template-addOpinion").innerHTML
    }

];



function createHtml4opinions(targetElmId){


    const init={
        headers: window.opHandler.back4appHeaders
    };


    fetch(window.opHandler.back4appUrl,init)
        .then(response =>{      //fetch promise fullfilled (operation completed successfully)
            if(response.ok){    //successful execution includes an error response from the server. So we have to check the return status of the response here.
                return response.json(); //we return a new promise with  the response data in JSON to be processed
            }else{ //if we get server error
                return Promise.reject(new Error(`Server answered with ${response.status}: ${response.statusText}.`)); //we return a rejected promise to be catched later
            }
        })
        .then(responseJSON => { //here we process the returned response data in JSON ...
            console.log(responseJSON);
            document.getElementById(targetElmId).innerHTML =
                Mustache.render(document.getElementById("template-opinions").innerHTML, responseJSON.results);
        })
        .catch (error => { ////here we process all the failed promises
            document.getElementById(targetElmId).innerHTML = error;
        });
}
